Rapporten | OiRA

Thema's

# Rapporten

U kunt een rapport gebruiken om:

- te dienen als bewijs voor toezichthoudende instanties;
- informatie te verstrekken aan belanghebbenden (werknemers, veiligheidsvertegenwoordigers, werkgevers, deskundigen op het gebied van veiligheid en gezondheid op het werk, enz.);
- te controleren en beoordelen of de vereiste maatregelen zijn genomen;
- eventuele herzieningen vast te leggen wanneer de omstandigheden veranderen (nieuwe machines/werknemers, of naar aanleiding van de bevindingen van eventuele ongevallenonderzoeken, enz.).

U kunt het rapport opslaan op uw computer en afdrukken. U kunt het rapport ook aanpassen of meer informatie aan het rapport toevoegen. NB Eventuele wijzigingen die u in een gedownload rapport hebt aangebracht, worden NIET opgeslagen in de OiRA-tool.

## Keuze uit verschillende rapporten

Er zijn verschillende soorten rapporten voor verschillende doeleinden. Welke rapporten beschikbaar zijn in de specifieke tools is afhankelijk van de door de nationale OiRA-partner/toolontwikkelaar gekozen configuratie.

Beschikbare rapporten.

### Volledig rapport

Format: Word / Office Open XML (.docx). Kan door u na het downloaden worden bewerkt.

Bevat alle informatie en input die u in de loop van het risicobeoordelingsproces hebt ingevoerd.

Kan worden gebruikt om: te dienen als bewijs van de risicobeoordeling voor toezichthoudende instanties (bv. de arbeidsinspectie).

### Actieplan

Format: Excel / Office Open XML (.xlsx). Kan na downloaden door u worden bewerkt

Bevat informatie over alle maatregelen waartoe u besloten hebt.

Kan worden gebruikt om:

- te dienen als actieve follow-up van de uitvoering van de maatregelen waarvoor u hebt gekozen;
- de problemen/risico’s op uw werkplek te beheren (specifieke taken, expertise, verantwoordelijkheden, uiterste termijnen).

### Risico-overzicht

Format: Portable Document Format (.pdf). Kan na het downloaden niet meer door u worden bewerkt.

Bevat een overzicht van de vastgestelde risico’s

Kan worden gebruikt om:

- een beknopt overzicht te geven van de status van de risico’s op uw werkplek;
- informatie te verstrekken aan belanghebbenden;
- te controleren of risico’s/maatregelen naar behoren zijn afgehandeld.

### Overzicht van maatregelen

Format: Portable Document Format (.pdf). Kan na het downloaden niet meer door u worden bewerkt.

Bevat een beknopt overzicht van de te nemen maatregelen.

Kan worden gebruikt om:

- een beknopt overzicht te geven van de maatregelen waartoe u besloten hebt;
- informatie te verstrekken aan belanghebbenden;
- te controleren of risico’s/maatregelen naar behoren zijn afgehandeld.

Scroll to top Load toolbar…
Back

## 4-reports.md

Help

Standard search Advanced search

- Splash and Shine Cleaners Last saved 19 days ago based on EU Cleaning More
- Commercial Guardinng, Leicester Last saved 2 months ago based on Private Security EU More
- Private Security, Grafton Street Last saved 2 months ago based on Private Security EU More
- Office operations in times of COVID-19 Last saved 4 months ago based on COVID-19 More